@@ -31,7 +31,7 @@ CMDLINE_ARGS=("$@")
        GUI_TERM="urxvt"
       TERM_OPTS="-e"
  TERM_TITLE_OPT="--title"
-     GUI_FILERS="rox thunar spacefm"
+     GUI_FILERS="rox thunar spacefm zzzfm dolphin"
 
         ARCHIVE="archive"
 
@@ -57,7 +57,6 @@ STD_OPTIONS="
     n,noco,nocolor||COLOR_OFF
     q,quiet||QUIET
     v,verbose||VERBOSE
-    no-yad||NO_YAD
 "
 
 SIZE_CHOICE="
@@ -128,14 +127,13 @@ check_for_yad() {
         unset SET_GUI
         return
     fi
-    which $GUI_TERM &> /dev/null || exit
-    vmsg "$(printf "No yad found.  Trying to open a %s window  ..." $GUI_TERM)"
+    vmsg "$(printf "No yad found.")"
     for arg in ${CMDLINE_ARGS[@]}; do
         args="$args $arg"
     done
-    vmsg "$GUI_TERM -e bash -c \"$0 $args --cli; bash\""
+    vmsg "exec $0 $args --cli"
     clean_up
-    $GUI_TERM -e bash -c "$0 $args --cli; bash" &>/dev/null &
+    exec $0 $args --cli
     exit
 }
 
@@ -155,7 +153,6 @@ $(gt "Usage"): [p]$ME[/] [$(gt "options")] $USAGE_ARGS
     -n|--nocolor     $(gt_ac "Turn off console colors")
        --nolog       $(gt_ac "Turn off logging")
     -q|--quiet       $(gt_ac "Suppress extra questions and printing")
-       --no-yad      $(gt_ac "Pretend yad does not exist")
     -v|--verbose     $(gt_ac "Print more")
 $EXTRA_USAGE
 [b]$(gt_ac "Debug options"):[/]
@@ -942,8 +939,8 @@ clean_up() {
     delete_files_rf $TEMP_DIR
 
     local luks
-    for luks in LUKS_CLOSE; do
-        /sbin/cryptsetup luksClose $luks
+    for luks in ${LUKS_CLOSE}; do
+        /usr/sbin/cryptsetup luksClose $luks
     done
 
     # Save log file to /root/Live-usb-storage/live-logs/ if available
@@ -1394,15 +1391,21 @@ device_info() {
     blkid | while read dev attribs; do
         dev=${dev%:}
         case "$dev" in
-            /dev/sd[a-z][0-9]*|/dev/hd[a-z][0-9]*)  ;;
-                                                *)  continue;;
+            /dev/hd[a-z]*[0-9])            ;;
+            /dev/sd[a-z]*[0-9])            ;;
+            /dev/vd[a-z]*[0-9])            ;;
+            /dev/mmcblk[0-9]p*[0-9])       ;;
+            /dev/nvme*[0-9]n*[0-9]p*[0-9]) ;;
+                               *) continue ;;
         esac
 
         TYPE= ; LABEL= ;
 
         eval "$attribs"
 
-        [ "$TYPE" = "swap" ] && continue
+        [ "$TYPE"  = "swap"      ] && continue
+        [ "$TYPE"  = "BitLocker" ] && continue
+        [ "x$TYPE" = "x"         ] && continue
 
         if [ "$dev" = "$rootdev" ]; then
             mount=$(grep "^/dev/root " /proc/mounts | head -n1 | cut -d" " -f2)
