@@ -137,13 +137,13 @@ vmsg() {
 
     #echo -e "$(date "+%F %T"): $text"  | sed -r "s:\x1B\[[0-9;]*[mK]::g" >> $LOG_FILE
     #echo -e "$(date "+%F %T"): $text" >> $LOG_FILE
-    echo -e "$text" >> $LOG_FILE
+    echo -e "$text"  | strip_ansi >> $LOG_FILE
 }
 
 qmsg() {
     local text="$(markup_text "$@")"
     echo -e "$text"
-    echo -e "$text" >> $LOG_FILE
+    echo -e "$text" | strip_ansi >> $LOG_FILE
 }
 
 # Verbose exit, explaining why we are leaving.
@@ -183,6 +183,17 @@ get_text() {
     fi
 }
 
+get_password() {
+    unset UI_RESULT
+    if [ "$SET_GUI" ]; then
+        _dialog_box_gui password "$@"
+        return $?
+    else
+        get_text_cli "$@"
+        return $?
+    fi
+}
+
 combo_box() {
     unset UI_RESULT
     if [ "$SET_GUI" ]; then
@@ -255,7 +266,7 @@ warn_box() {
 
 noisy_yes_no_box() {
     [ "$SET_QUIET" ] && return 0
-    yes_no_box "$@" 
+    yes_no_box "$@"
     return $?
 }
 
@@ -344,7 +355,7 @@ _dialog_box_gui() {
     opts="$YAD_STD_OPTS"
 
     case "$type" in
-        text|combo)
+        text|combo|password)
             opts="$opts $YAD_MULTI_OPTS"
             label="$1"
             choice="$2"
@@ -359,6 +370,7 @@ _dialog_box_gui() {
             -c) center=true     && shift;;
             -o) opts="$opts $2" && shift 2;;
             --) notitle=true    && shift;;
+            -n) notitle=true    && shift;;
             -a) shift;;
             -q) shift;;
              *) break;;
@@ -372,6 +384,7 @@ _dialog_box_gui() {
          error)  opts="$opts $YAD_ERROR_OPTS";;
           exit)  opts="$opts $YAD_EXIT_OPTS";;
           text)  field_type="";;
+      password)  field_type="H";;
          combo)  field_type="CB";;
 
              *)  echo "$ME: internal error: no \"$1\" _multi_box"
@@ -507,7 +520,12 @@ _dialog_box_cli() {
         return 0
     fi
 
-    read input
+    MY_TTY="$(tty)" #workout to get tty access for runit shutdown
+    if [ -n "$MY_TTY" ] && [ -e "$MY_TTY" ]; then
+        read input <$MY_TTY
+    else
+        read input
+    fi
     echo
     [ "$input" ] || input="$default"
 
